==> haskell-hxt-charproperties-9.2.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-charproperties
version: 9.2.0.1
id: hxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh
key: hxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh
license: MIT
copyright: Copyright (c) 2010-2014 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Character properties and classes for XML and Unicode
description:
    Character proprties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 7.0.0
category: Text
author: Uwe Schmidt
exposed: True
indefinite: False
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet
abi: f123fbce30d0a477393b885fa468c37f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hxt-charproperties-9.2.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/hxt-charproperties-9.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/hxt-charproperties-9.2.0.1
hs-libraries: HShxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock
haddock-html: /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-charproperties-9.2.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-charproperties
version: 9.2.0.1
id: hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
key: hxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
license: MIT
copyright: Copyright (c) 2010-2014 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Character properties and classes for XML and Unicode
description:
    Character proprties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 7.0.0
category: Text
author: Uwe Schmidt
exposed: True
indefinite: False
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet
abi: 128140e73626722dd834f67c7ef8810c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-charproperties-9.2.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hxt-charproperties-9.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hxt-charproperties-9.2.0.1
hs-libraries: HShxt-charproperties-9.2.0.1-AUb7E6mkZ2fDXtvIiRtV8v
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock
haddock-html: /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
